@@ -1,19 +1,23 @@
-# $Id: Currency.pm 366 2005-03-09 03:37:35Z claco $
+# $Id: Currency.pm 386 2005-03-11 01:05:25Z claco $
 package AxKit::XSP::Currency;
 use strict;
 use warnings;
 use vars qw($VERSION $NS @EXPORT_TAGLIB);
 use base 'Apache::AxKit::Language::XSP::TaglibHelper';
 use Locale::Currency::Format;
+use Finance::Currency::Convert::WebserviceX;
 
-$VERSION = '0.07';
+$VERSION = '0.08';
 $NS  = 'http://today.icantfocus.com/CPAN/AxKit/XSP/Currency';
 
 @EXPORT_TAGLIB = (
     'format($price;$code,$options)',
-    'symbol(;$code,$options)'
+    'symbol(;$code,$options)',
+    'convert($price,$from,$to)',
 );
 
+my $cc = Finance::Currency::Convert::WebserviceX->new();
+
 sub format {
     my ($price, $code, $options) = @_;
 
@@ -36,6 +40,14 @@ sub symbol {
     return currency_symbol($code, $options);
 };
 
+sub convert {
+    my ($price, $from, $to) = @_;
+
+    $from ||= 'USD';
+
+    return $cc->convert($price, $from, $to);
+};
+
 1;
 __END__
 
@@ -62,7 +74,7 @@ Add the namespace to your XSP file and use the tags:
 
     <currency:format>
         <currency:code>USD</currency:code>
-        <currenct:options>FMT_HTML</currency:options>
+        <currency:options>FMT_HTML</currency:options>
         <currency:price>10.95</currenct:price>
     </currency:format>
 
@@ -78,15 +90,27 @@ conversion is planned for future releases.
 
 =head1 TAG HIERARCHY
 
-    <currency:format code="USD|CAD|..." options="FMT_STANDARD|FMT_COMMON|...">
+    <currency:format code="USD|CAD|..." options="FMT_STANDARD|FMT_COMMON|..." price="10.95">
         <currency:code></currency:code>
         <currency:options></currency:options>
-        <currency:price></currency:price>
+        <currency:price>10.95</currency:price>
+        <convert:price>
+            <currency:convert from="USD|CAD|JPY|..." price="10.95" to="CAD|JPY|...">
+                <currency:from></currency:from>
+                <currency:price</currency:price>
+                <currency:to></currency:to>
+            </currency:convert>
+        </convert:price>
     </currency:format>
     <currency:symbol code="USD|CAD|..." options="SYM_HTML|SYM_UTF">
         <currency:code></currency:code>
         <currency:options></currency:options>
     </currency:symbol>
+    <currency:convert from="USD|CAD|JPY|..." price="10.95" to="CAD|JPY|...">
+        <currency:from></currency:from>
+        <currency:price</currency:price>
+        <currency:to></currency:to>
+    </currency:convert>
 
 =head1 TAG REFERENCE
 
@@ -137,6 +161,17 @@ the more common usage will be as a child tag:
         <currency:price>19.95</currency:price>
     </currency:format>
 
+You can also next a C<convert> tag inside of C<price> to format the results
+of a currency conversion:
+
+    <convert:price>
+        <currency:convert from="USD|CAD|JPY|..." price="10.95" to="CAD|JPY|...">
+            <currency:from></currency:from>
+            <currency:price</currency:price>
+            <currency:to></currency:to>
+        </currency:convert>
+    </convert:price>
+
 =back
 
 =head2 <currency:symbol>
@@ -176,6 +211,54 @@ See L<Locale::Currency::Format> for all of the available format options.
 
 =back
 
+=head2 <currency:convert>
+
+Converts a price from one currency to another using L<Finance::Currency::Convert::WebserviceX>.
+
+    <currency:convert from="USD|CAD|JPY|..." price="10.95" to="CAD|JPY|...">
+        <currency:from></currency:from>
+        <currency:price</currency:price>
+        <currency:to></currency:to>
+    </currency:convert>
+
+The C<convert> tag has three available attributes to control the output:
+
+=over
+
+=item from
+
+This is the 3 letter currency code used to specify the currency in use.
+The C<from> attribute can also be specified using a child tag instead:
+
+    <currency:convert>
+        <currency:from>USD</currency:from>
+    </currency:convert>
+
+C<USD> is used as the default if no currency code is specified.
+See L<Locale::Currency> for all of the available currency codes.
+
+=item price
+
+This is the price to be formatted. While it can be passed as an attribute,
+the more common usage will be as a child tag:
+
+    <currency:convert>
+        <currency:price>19.95</currency:price>
+    </currency:convert>
+
+=item to
+
+This is the 3 letter currency code used to specify the currency in use.
+The C<to> attribute can also be specified using a child tag instead:
+
+    <currency:convert>
+        <currency:to>USD</currency:to>
+    </currency:convert>
+
+See L<Locale::Currency> for all of the available currency codes.
+
+=back
+
 =head1 SEE ALSO
 
 L<Locale::Currency::Format>
@@ -184,5 +267,5 @@ L<Locale::Currency::Format>
 
     Christopher H. Laco
     CPAN ID: CLACO
-    cpan@chrislaco.com
+    claco@chrislaco.com
     http://today.icantfocus.com/blog/
